from .lazygit import Lazygit
from .lf import Lf
from .mpv import Mpv
from .neovim import Neovim
from .qutebrowser import Qutebrowser
from .rofi import Rofi
from .sxhkd import Sxhkd
from .sxiv import Sxiv
from .termite import Termite
from .vim import Vim
from .vimiv import Vimiv
from .zathura import Zathura
from .zsh import Zsh

__all__ = [
    "Lazygit",
    "Lf",
    "Mpv",
    "Neovim",
    "Qutebrowser",
    "Rofi",
    "Sxhkd",
    "Sxiv",
    "Termite",
    "Vim",
    "Vimiv",
    "Zathura",
    "Zsh",
]
